=========
Changelog
=========

unreleased
----------

0.1.0 - 2023-12-19
------------------

- Add templatetags to clean HTML within django templates by `@wes-otf`_ in `PR 16`_.

.. _@wes-otf: https://github.com/wes-otf
.. _PR 16: https://github.com/marksweb/django-nh3/pull/16

0.0.3 - 2023-11-15
------------------

- Added pypi publishing

0.0.2 - 2023-11-15
------------------

- Added model field with NH3 sanitization
- Added testing against django 5.0


0.0.1 - 2023-03-02
------------------

- Initial release offering a form field with NH3 sanitization
